from math import pi


EPS = 1e-6
polygon = []
n = int()

class Point:
    def __init__(self, x = 0, y = 0):
        self.x = x
        self.y = y

    def __sub__(self, other):
        return Point(self.x - other.x, self.y - other.y)
    
    def __mul__(self, other):
        return self.x * other.x + self.y * other.y

    def __xor__(self, other):
        return self.x * other.y - self.y * other.x

    def square_dist(self):
        return self.x ** 2 + self.y ** 2

    def dist(self):
        return self.square_dist() ** 0.5
    
    def __eq__(self, other):
        return self.x == other.x and self.y == other.y
    
def is_inside_triangle(a, b, c, p):
    return ((b - a) ^ (p - a)) >= 0 and ((c - b) ^ (p - b)) >= 0 and ((a - c) ^ (p - c)) >= 0

def is_inside(p):
    global polygon
    global n
    if polygon[0] == p:
        return True
    if ((polygon[1] - polygon[0]) ^ (p - polygon[0])) < 0:
        return False
    if ((polygon[n - 1] - polygon[0]) ^ (p - polygon[0])) > 0:
        return False
    if ((polygon[1] - polygon[0]) ^ (p - polygon[0])) == 0:
        return is_inside_triangle(polygon[0], polygon[1], polygon[2], p)
    if ((polygon[n - 1] - polygon[0]) ^ (p - polygon[0])) == 0:
        return is_inside_triangle(polygon[0], polygon[n - 2], polygon[n - 1], p)
    l, r = 1, n - 1
    while r - l > 1:
        m = (l + r) // 2
        if ((polygon[m] - polygon[0]) ^ (p - polygon[0])) >= 0:
            l = m
        else:
            r = m
    return is_inside_triangle(polygon[0], polygon[l], polygon[l + 1], p)

def find_one_tangent(p, dir, l, r):
    global polygon
    global n
    while r - l > 1:
        m = (l + r) // 2
        pvs = (((polygon[m] - p) ^ (polygon[(m + n - 1) % n] - p)) * dir >= 0)
        nxt = (((polygon[m] - p) ^ (polygon[(m + 1) % n] - p)) * dir >= 0)
        if pvs and nxt:
            return m
        if not pvs and not nxt:
            p1 = find_one_tangent(p, dir, m + 1, r)
            p2 = find_one_tangent(p, dir, l, m - 1)
            return p1 if (((polygon[p1] - p) ^ (polygon[p2] - p)) * dir > 0) else p2
        if not pvs:
            if ((polygon[m] - p) ^ (polygon[l] - p)) * dir > 0:
                r = m - 1
            elif ((polygon[l] - p) ^ (polygon[r] - p)) * dir > 0:
                r = m - 1
            else:
                l = m + 1
        if not nxt:
            if ((polygon[m] - p) ^ (polygon[l] - p)) * dir > 0:
                l = m + 1
            elif ((polygon[l] - p) ^ (polygon[r] - p)) * dir > 0:
                r = m - 1
            else:
                l = m + 1
    ret = l
    for i in range(l + 1, r + 1):
        ret = i if ((polygon[ret] - p) ^ (polygon[i] - p)) * dir <= 0 else ret
    return ret

def find_tangents(p):
    global n
    return [find_one_tangent(p, -1, 0, n - 1), find_one_tangent(p, 1, 0, n - 1)]

def find_dist_segment(a, b, p):
    if (((b - a) * (p - a)) > 0 and ((a - b) * (p - b)) > 0):
        return 1.0 * abs((a - p) ^ (b - p)) / (a - b).dist()
    return (min((a - p).square_dist(), (b - p).square_dist())) ** 0.5

def find_dist_two_segments(a, b, c, p):
    d1 = find_dist_segment(a, b, p)
    d2 = find_dist_segment(b, c, p)
    if d1 < d2 + EPS:
        return d1
    return d2

def find_dist(p):
    global polygon
    global n
    if is_inside(p):
        return 0.0
    pr = find_tangents(p)
    l, r = pr[0], pr[1]
    if r < l:
        r += n
    while r - l > 2:
        m1 = (l + l + r) // 3
        m2 = (l + r + r) // 3
        if ((polygon[m1 % n] - p).square_dist() <= (polygon[m2 % n] - p).square_dist()):
            r = m2
        if ((polygon[m1 % n] - p).square_dist() >= (polygon[m2 % n] - p).square_dist()):
            l = m1
    if r - l == 1:
        return find_dist_segment(polygon[l % n], polygon[r % n], p)
    return find_dist_two_segments(polygon[l % n], polygon[(l + 1) % n], polygon[r % n], p)

n = int(input())
s, p = 0., 0.
for i in range(n):
    x, y = map(int, input().split())
    polygon.append(Point(x, y))
    if i != 0:
        s += polygon[i - 1] ^ polygon[i]
        p += (polygon[i - 1] - polygon[i]).dist()
s += polygon[n - 1] ^ polygon[0]
p += (polygon[n - 1] - polygon[0]).dist()
s /= 2
days = []
pow2 = 1.
for i in range(71):
    a, b, c = pi, p, s * (1 - pow2)
    pow2 *= 2
    days.append((-b + (b ** 2 - 4. * a * c) ** 0.5) / (2. * a))
q = int(input())
for _ in range(q):
    x, y = map(int, input().split())
    city = Point(x, y)
    d = find_dist(city)
    for i in range(71):
        if days[i] - d > -EPS:
            print(i)
            break