#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>

#define sqr(x) ((x)*(x))

using namespace std;

const double EPS = 1e-6;
const double PI = acos(-1);

struct Point {
	long long x, y;
	
	Point() {}
	Point(long long _x, long long _y) : x(_x), y(_y) {}
	
	inline Point operator- (const Point& a) {
		return Point(x - a.x, y - a.y);
	}
	
	inline long long operator^ (const Point& p) {
		return x * p.y - y * p.x;
	}
	
	inline long long operator* (const Point& p) {
		return x * p.x + y * p.y;
	}
	
	inline long long dist2() {
		return sqr(x) + sqr(y);
	}
	
	inline double dist() {
		return sqrt(dist2());
	}
	
	inline bool operator== (const Point& p) {
		return x == p.x && y == p.y;
	}
};

int n;
vector <Point> polygon;

bool is_inside(Point& p) {
	bool ans = ((polygon[0] - polygon[n - 1]) ^ (p - polygon[n - 1])) >= 0;
	for (int i = 0; i < n - 1; i++)
		ans &= ((polygon[i + 1] - polygon[i]) ^ (p - polygon[i])) >= 0;
	return ans;
}

inline double find_dist_segment(Point& a, Point& b, Point& p) {
	if (((b - a) * (p - a)) > 0 && ((a - b) * (p - b)) > 0)
		return 1.0 * abs((a - p) ^ (b - p)) / (a - b).dist();
	return sqrt(min((a - p).dist2(), (b - p).dist2()));
}

double find_dist(Point& p) {
	if (is_inside(p)) return 0.0;
	
	double ans = find_dist_segment(polygon[n - 1], polygon[0], p);
	for (int i = 0; i < n - 1; i++) {
		double curd = find_dist_segment(polygon[i], polygon[i + 1], p);
		if (ans - curd > EPS)
			ans = curd;
	}
	return ans;
}

int main() {
	cin >> n;
	
	polygon.resize(n);
	double s = 0, p = 0;
	for (int i = 0; i < n; i++) {
		cin >> polygon[i].x >> polygon[i].y;
		if (i) {
			s += polygon[i - 1] ^ polygon[i];
			p += (polygon[i - 1] - polygon[i]).dist();
		}
	}
	s += polygon[n - 1] ^ polygon[0];
	p += (polygon[n - 1] - polygon[0]).dist();
	s /= 2.0;
	
	vector <double> days;
	double pow2 = 1;
	for (int i = 0; i < 71; i++) {
		double a = PI, b = p, c = s * (1 - pow2);
		pow2 *= 2.0;
		days.push_back((-b + sqrt(sqr(b) - 4.0 * a * c)) / (2.0 * a));
	}
	
	int q;
	cin >> q;
	while (q--) {
		Point city;
		cin >> city.x >> city.y;
		double d = find_dist(city);
		
		for (int i = 0; i < 71; i++) {
			if (days[i] - d > -EPS) {
				cout << i << '\n';
				break;
			}
		}
	}
	
	return 0;
}