/**
 *    author:  tourist
 *    created: 13.10.2023 01:18:02       
**/
#include <bits/stdc++.h>

using namespace std;

#ifdef LOCAL
#include "algo/debug.h"
#else
#define debug(...) 42
#endif

template <typename T>
class graph {
 public:
  struct edge {
    int from;
    int to;
    T cost;
  };

  vector<edge> edges;
  vector<vector<int>> g;
  int n;

  graph(int _n) : n(_n) {
    g.resize(n);
  }

  virtual int add(int from, int to, T cost) = 0;
};

template <typename T>
class undigraph : public graph<T> {
 public:
  using graph<T>::edges;
  using graph<T>::g;
  using graph<T>::n;

  undigraph(int _n) : graph<T>(_n) {
  }

  int add(int from, int to, T cost = 1) {
    assert(0 <= from && from < n && 0 <= to && to < n);
    int id = (int) edges.size();
    g[from].push_back(id);
    g[to].push_back(id);
    edges.push_back({from, to, cost});
    return id;
  }
};

template <typename T>
vector<T> dijkstra(const graph<T> &g, int start) {
  assert(0 <= start && start < g.n);
  vector<T> dist(g.n, numeric_limits<T>::max());
  priority_queue<pair<T, int>, vector<pair<T, int>>, greater<pair<T, int>>> s;
  dist[start] = 0;
  s.emplace(dist[start], start);
  while (!s.empty()) {
    T expected = s.top().first;
    int i = s.top().second;
    s.pop();
    if (dist[i] != expected) {
      continue;
    }
    for (int id : g.g[i]) {
      auto &e = g.edges[id];
      int to = e.from ^ e.to ^ i;
      if (dist[i] + e.cost < dist[to]) {
        dist[to] = dist[i] + e.cost;
        s.emplace(dist[to], to);
      }
    }
  }
  return dist;
  // returns numeric_limits<T>::max() if there's no path
}

int main() {
  ios::sync_with_stdio(false);
  cin.tie(0);
  int h, w, k;
  cin >> h >> w >> k;
  vector<string> s(h);
  for (int i = 0; i < h; i++) {
    cin >> s[i];
  }
  int si, sj, fi, fj;
  cin >> si >> sj >> fi >> fj;
  --si; --sj; --fi; --fj;
  undigraph<int> g(h * w);
  for (int i = 0; i < h; i++) {
    for (int j = 0; j < w; j++) {
      if (s[i][j] != '.') {
        continue;
      }
      if (i + 1 < h && s[i + 1][j] == '.') {
        g.add(i * w + j, (i + 1) * w + j, 0);
      }
      if (i + 2 < h && s[i + 2][j] == '.') {
        g.add(i * w + j, (i + 2) * w + j, 1);
      }
      if (j + 1 < w && s[i][j + 1] == '.') {
        g.add(i * w + j, i * w + (j + 1), 0);
      }
      if (j + 2 < w && s[i][j + 2] == '.') {
        g.add(i * w + j, i * w + (j + 2), 1);
      }
    }
  }
  auto d = dijkstra(g, si * w + sj);
  cout << (d[fi * w + fj] <= k ? "YES" : "NO") << '\n';
  return 0;
}
